@@ -29,9 +29,10 @@ release = version
 # directories to ignore when looking for source files.
 exclude_patterns = ['_build']
 
-# If we don't have emacs, don't build the notmuch-emacs docs, as they need
-# emacs to generate the docstring include files
-if os.environ.get('HAVE_EMACS') != '1':
+# If we don't have emacs (or the user configured --without-emacs),
+# don't build the notmuch-emacs docs, as they need emacs to generate
+# the docstring include files
+if os.environ.get('HAVE_EMACS') != '1' or os.environ.get('WITH_EMACS') != '1':
     exclude_patterns.append('notmuch-emacs.rst')
 
 # The name of the Pygments (syntax highlighting) style to use.
